@@ -34,6 +34,7 @@
 #'   will not work.
 #' @param data Optional argument, only needed if models are not hierarchical.
 #'   Dataset with rows denoting observations and columns denoting variables.
+#' @param bargraph Optional bar graph output, default is TRUE.
 #'
 #' @return If the inputs are valid models, then the output will be a list and
 #'   associated graphical representation of R-squared decompositions. If the
@@ -44,7 +45,7 @@
 #' # Using lme4 for your model
 #' # The "bobyqa" optimizer is required for these particular models to converge
 #'
-#' # Model A, no "salary" components included
+#'\dontrun{ # Model A, no "salary" components included
 #'
 #' modelA_lme4 <- lmer(satisfaction ~ 1 + control_c + control_m + s_t_ratio + (1
 #' + control_c | schoolID), data = teachsat, REML = TRUE, control =
@@ -86,15 +87,15 @@
 #'
 #' # Compare models, optional data argument specified
 #' r2mlm_comp(modelA_nlme, modelB_nlme, teachsat)
+#'}
 #'
-#' @seealso \href{https://doi.org/10.1037/met0000184}{Rights, J. D., & Sterba,
-#'   S. K. (2019). Quantifying explained variance in multilevel models: An
-#'   integrative framework for defining R-squared measures. Psychological
-#'   Methods, 24(3), 309–338.}
-#' @seealso \href{https://doi.org/10.1080/00273171.2019.1660605}{Rights, J. D., &
-#'   Sterba, S. K. (2020). New recommendations on the use of R-squared
-#'   differences in multilevel model comparisons. Multivariate Behavioral
-#'   Research.}
+#' @seealso Rights, J. D., & Sterba, S. K. (2019). Quantifying explained
+#'   variance in multilevel models: An integrative framework for defining
+#'   R-squared measures. Psychological Methods, 24(3), 309–338.
+#'   <doi:10.1037/met0000184>
+#' @seealso Rights, J. D., & Sterba, S. K. (2020). New recommendations on the
+#'   use of R-squared differences in multilevel model comparisons. Multivariate
+#'   Behavioral Research. <doi:10.1080/00273171.2019.1660605>
 #'
 #' @family r2mlm model comparison functions
 #'
@@ -109,7 +110,7 @@
 
 # 1 r2mlm_comp_wrapper -----------------------------------------------------
 
-r2mlm_comp <- function(modelA, modelB, data = NULL) {
+r2mlm_comp <- function(modelA, modelB, data = NULL, bargraph = TRUE) {
 
   # throw error if model contains higher-order terms
   temp_formula <- formula(modelA)
@@ -136,9 +137,9 @@ r2mlm_comp <- function(modelA, modelB, data = NULL) {
   }
 
   if (typeof(modelA) == "list") {
-    r2mlm_comp_nlme(modelA, modelB, data)
+    r2mlm_comp_nlme(modelA, modelB, data, bargraph)
   } else if (typeof(modelA) == "S4") {
-    r2mlm_comp_lmer(modelA, modelB, data)
+    r2mlm_comp_lmer(modelA, modelB, data, bargraph)
   } else {
     stop("Error. You must input models generated using either the lme4 or nlme package.")
   }
@@ -147,7 +148,7 @@ r2mlm_comp <- function(modelA, modelB, data = NULL) {
 
 # 2 r2mlm_comp_lmer --------------------------------------------------------
 
-r2mlm_comp_lmer <- function(modelA, modelB, data) {
+r2mlm_comp_lmer <- function(modelA, modelB, data, bargraph) {
 
   # r2mlm_ wrapper sub-functions, but for modelA
 
@@ -226,6 +227,12 @@ r2mlm_comp_lmer <- function(modelA, modelB, data) {
     centeredwithincluster <- get_cwc(l1_vars_A, cluster_variable, data)
   }
 
+  # * Step 6b) r2mlm_comp requires that both models be centeredwithincluster. If they aren't, then throw an error.
+
+  if (centeredwithincluster == FALSE) {
+    stop("When using r2mlm_comp() to compare models, both models must have level-1 predictors centered within cluster.")
+  }
+
   # Step 7) pull column numbers for _covs variables
   # 7a) within_covs (l1 variables)
   # for (each value in l1_vars list) {match(value, names(data))}
@@ -334,6 +341,12 @@ r2mlm_comp_lmer <- function(modelA, modelB, data) {
     centeredwithincluster <- get_cwc(l1_vars_B, cluster_variable, data)
   }
 
+  # * Step 6b) r2mlm_comp requires that both models be centeredwithincluster. If they aren't, then throw an error.
+
+  if (centeredwithincluster == FALSE) {
+    stop("When using r2mlm_comp() to compare models, both models must have level-1 predictors centered within cluster.")
+  }
+
   # Step 7) pull column numbers for _covs variables
   # 7a) within_covs (l1 variables)
   # for (each value in l1_vars list) {match(value, names(data))}
@@ -380,13 +393,13 @@ r2mlm_comp_lmer <- function(modelA, modelB, data) {
   sigma2_B <- lme4::getME(modelB, "sigma")^2
 
 
-  r2mlm_comp_manual(as.data.frame(data), within_covs_modA = within_A, between_covs_modA = between_A, random_covs_modA = random_A, gamma_w_modA = gammaw_A, gamma_b_modA = gammab_A, Tau_modA = tau_A, sigma2_modA = sigma2_A, within_covs_modB = within_B, between_covs_modB = between_B, random_covs_modB = random_B, gamma_w_modB = gammaw_B, gamma_b_modB = gammab_B, Tau_modB = tau_B, sigma2_modB = sigma2_B)
+  r2mlm_comp_manual(as.data.frame(data), within_covs_modA = within_A, between_covs_modA = between_A, random_covs_modA = random_A, gamma_w_modA = gammaw_A, gamma_b_modA = gammab_A, Tau_modA = tau_A, sigma2_modA = sigma2_A, within_covs_modB = within_B, between_covs_modB = between_B, random_covs_modB = random_B, gamma_w_modB = gammaw_B, gamma_b_modB = gammab_B, Tau_modB = tau_B, sigma2_modB = sigma2_B, bargraph = bargraph)
 
 }
 
 # 3 r2mlm_comp_nlme --------------------------------------------------------
 
-r2mlm_comp_nlme <- function(modelA, modelB, data) {
+r2mlm_comp_nlme <- function(modelA, modelB, data, bargraph) {
 
   # EXTRACT FOR MODEL A
 
@@ -464,6 +477,12 @@ r2mlm_comp_nlme <- function(modelA, modelB, data) {
     centeredwithincluster <- get_cwc(l1_vars_A, cluster_variable, data)
   }
 
+  # * Step 6b) r2mlm_comp requires that both models be centeredwithincluster. If they aren't, then throw an error.
+
+  if (centeredwithincluster == FALSE) {
+    stop("When using r2mlm_comp() to compare models, both models must have level-1 predictors centered within cluster.")
+  }
+
   # Step 7) pull column numbers for _covs variables
   # 7a) within_covs (l1 variables)
   # for (each value in l1_vars list) {match(value, names(data))}
@@ -571,6 +590,12 @@ r2mlm_comp_nlme <- function(modelA, modelB, data) {
     centeredwithincluster <- get_cwc(l1_vars_B, cluster_variable, data)
   }
 
+  # * Step 6b) r2mlm_comp requires that both models be centeredwithincluster. If they aren't, then throw an error.
+
+  if (centeredwithincluster == FALSE) {
+    stop("When using r2mlm_comp() to compare models, both models must have level-1 predictors centered within cluster.")
+  }
+
   # Step 7) pull column numbers for _covs variables
   # 7a) within_covs (l1 variables)
   # for (each value in l1_vars list) {match(value, names(data))}
@@ -619,6 +644,6 @@ r2mlm_comp_nlme <- function(modelA, modelB, data) {
 
   # Step 11) input everything into r2mlm_comp_manual
 
-  r2mlm_comp_manual(as.data.frame(data), within_covs_modA = within_A, between_covs_modA = between_A, random_covs_modA = random_A, gamma_w_modA = gammaw_A, gamma_b_modA = gammab_A, Tau_modA = tau_A, sigma2_modA = sigma2_A, within_covs_modB = within_B, between_covs_modB = between_B, random_covs_modB = random_B, gamma_w_modB = gammaw_B, gamma_b_modB = gammab_B, Tau_modB = tau_B, sigma2_modB = sigma2_B)
+  r2mlm_comp_manual(as.data.frame(data), within_covs_modA = within_A, between_covs_modA = between_A, random_covs_modA = random_A, gamma_w_modA = gammaw_A, gamma_b_modA = gammab_A, Tau_modA = tau_A, sigma2_modA = sigma2_A, within_covs_modB = within_B, between_covs_modB = between_B, random_covs_modB = random_B, gamma_w_modB = gammaw_B, gamma_b_modB = gammab_B, Tau_modB = tau_B, sigma2_modB = sigma2_B, bargraph = bargraph)
 
 }
